@@ -153,7 +153,7 @@ def create_query_string(params):
         pair = param + '=' + random_str(4) + '&'
         query_string += pair
     if query_string.endswith('&'):
-	    query_string = query_string[:-1]
+        query_string = query_string[:-1]
     return '?' + query_string
 
 
@@ -180,6 +180,7 @@ def extract_js(response):
             scripts.append(actual_parts[0])
     return scripts
 
+
 def parse_headers(string):
     """
     parses headers
@@ -248,7 +249,7 @@ def fetch_params(host):
 def prepare_requests(args):
     """
     creates a list of request objects used by Arjun from targets given by user
-    returns list (of targs)
+    returns list (of targets)
     """
     headers = {
         'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64; rv:83.0) Gecko/20100101 Firefox/83.0',
@@ -258,6 +259,7 @@ def prepare_requests(args):
         'Connection': 'close',
         'Upgrade-Insecure-Requests': '1'
     }
+    result = []
     if type(args.headers) == str:
         headers = extract_headers(args.headers)
     elif args.headers:
@@ -266,15 +268,17 @@ def prepare_requests(args):
         headers['Content-type'] = 'application/json'
     if args.url:
         params = get_params(args.include)
-        return {
-            'url': args.url,
-            'method': mem.var['method'],
-            'headers': headers,
-            'include': params
-        }
+        result.append(
+            {
+                'url': args.url,
+                'method': mem.var['method'],
+                'headers': headers,
+                'include': params
+            }
+        )
     elif args.import_file:
-        return importer(args.import_file, mem.var['method'], headers, args.include)
-    return []
+        result = importer(args.import_file, mem.var['method'], headers, args.include)
+    return result
 
 
 def nullify(*args, **kwargs):
